ResourceMatcherRegistry

Struct ResourceMatcherRegistry 

pub struct ResourceMatcherRegistry { /* private fields */ }
Registry for custom resource matchers

Implementations

Source

impl ResourceMatcherRegistry

pub fn new() -> Self

Creates a new empty registry

pub fn register( &mut self, resource_type: impl Into<String>, matcher: Box<dyn ResourceMatcher>, ) -> Option<Box<dyn ResourceMatcher>>

Registers a new matcher for a resource type

Some(old_matcher) if there was a previous matcher, None if new

pub fn unregister( &mut self, resource_type: &str, ) -> Option<Box<dyn ResourceMatcher>>

Unregisters a matcher

Returns

Some(matcher) if it existed, None if it was not registered

pub fn has_matcher(&self, resource_type: &str) -> bool

Checks if there is a matcher registered for a type

pub fn matches(&self, pattern: &Resource, target: &Resource) -> bool

Executes matching using the appropriate matcher

If there is no custom matcher, it uses the default Resource::matches() method.

pub fn list_matchers(&self) -> Vec<String>

Lists all registered resource types

pub fn count(&self) -> usize

Counts the number of registered matchers

pub fn clear(&mut self)

Clears all matchers