PolicyBuilder

Struct PolicyBuilder 

pub struct PolicyBuilder { /* private fields */ }
Builder for creating Policy instances with a fluent API

Examples

use core_policy::{PolicyBuilder, PolicyRuleBuilder, Action, Resource};

let policy = PolicyBuilder::new("admin-policy")
    .add_rule_with(|rule| {
        rule.for_peer("12D3KooWAlice...")
            .allow(Action::All)
            .on(Resource::All)
    })
    .add_rule_with(|rule| {
        rule.for_peer("12D3KooWBob...")
            .allow(Action::Read)
            .on(Resource::File("/docs/*".into()))
    })
    .with_metadata("owner", "alice")
    .build()
    .unwrap();

Implementations

Source

impl PolicyBuilder

pub fn new(name: impl Into<String>) -> Self

Create a new policy builder with default validity (30 days)

pub fn with_timestamp(self, timestamp: u64) -> Self

Set the policy issuance timestamp (Unix seconds).

Required for valid time-based policies. If not set, defaults to 0.

pub const fn valid_for(self, duration_secs: u64) -> Self

Set policy validity duration in seconds

pub fn add_rule_with<F>(self, f: F) -> Self

Add a rule using a builder function

pub fn add_rule(self, rule: PolicyRule) -> Self

Add a pre-constructed rule

pub fn with_metadata( self, key: impl Into<String>, value: impl Into<String>, ) -> Self

Add metadata to the policy

pub fn build(self) -> Result<Policy>

Build the Policy, returning an error if validation fails

Errors

Returns an error if policy validation fails (see Policy::validate())