Path matching using a custom wildcard implementation to avoid external dependencies.
This module accepts wildcard forms commonly used in shells:
*- matches any sequence of characters except the path separator/?- matches a single character
NOTE: ** is not supported in this implementation and is treated as a literal *.
Security
Matches paths using a non-recursive, zero-allocation algorithm. Safe for use with untrusted inputs (guaranteed O(N) time complexity).
Examples
/home/*/documents/tmp/file?.txt
Structs
- Path
Pattern - Path pattern with wildcard support.